OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Контакти",
    "Download" : "Завантажити",
    "Copy link" : "Копіювати посилання",
    "Click to copy the link to your clipboard" : "Натисніть для копіювання посилання до буферу обміну",
    "Delete" : "Видалити",
    "Rename" : "Перейменувати",
    "Share with users or groups" : "Поділитися з користувачем або групою",
    "can edit" : "може редагувати",
    "Close" : "Закрити",
    "Enabled" : "Увімкнено",
    "Disabled" : "Вимкнено",
    "Copied!" : "Скопійовано!",
    "Not supported!" : "Не підтримується!",
    "Press ⌘-C to copy." : "Натисніть ⌘-C щоб скопіювати.",
    "Press Ctrl-C to copy." : "Натисніть Ctrl-C щоб скопіювати.",
    "Address book name" : "Назва адресної книги",
    "Only these special characters are allowed: -_.!?#|()" : "Дозволено лише наступні спеціальні символи: -_.!?#|()",
    "Address book could not be created." : "Не вдалося створити адресну книгу",
    "The selected image is too big (max 1MB)" : "Обране зображення занадто велике (1МБ max)",
    "No contacts in here" : "Тут немає контактів",
    "Name" : "Ім’я",
    "Organization" : "Організація",
    "Title" : "Назва",
    "Add field …" : "Додати поле …",
    "Save changes" : "Зберегти зміни",
    "Address book" : "Адресна книга",
    "Loading contacts …" : "Завантаження контактів …",
    "Import into" : "Імпортувати до",
    "Importing..." : "Імпортування…",
    "Select your addressbook" : "Оберіть адресну книгу",
    "No search result for {query}" : "Немає результатів пошуку для {query}",
    "All contacts" : "Всі контакти",
    "Post office box" : "Абонентська скринька",
    "Postal code" : "Поштовий індекс",
    "City" : "Місто",
    "State or province" : "Область або район",
    "Country" : "Країна",
    "Address" : "Адреса",
    "(new group)" : "(нова група)",
    "Last name" : "Прізвище",
    "First name" : "Ім'я",
    "Additional names" : "Додаткові імена",
    "Prefix" : "Префікс",
    "Suffix" : "Суфікс",
    "Importing into" : "Імпортування до",
    "New contact" : "Новий контакт",
    "Not grouped" : "Не згруповані",
    "Sort by" : "Сортувати за",
    "There is no address book available to create a contact." : "Тут немає адресної книги для створення контакту.",
    "{addressbook} shared by {owner}" : "{owner} поділився {addressbook}",
    "Contact not found." : "Контакт не знайдено",
    "You don't have permission to write to this addressbook." : "Вам бракує прав на запис до даної адресної книги.",
    "Contact could not be created." : "Неможливо створити контакт.",
    "No contacts in file. Only vCard files are allowed." : "Відсутні контакти в фалі. Дозволено лише vCard файли.",
    "Only vCard version 4.0 (RFC6350) or version 3.0 (RFC2426) are supported." : "Підтримуються лише vCard версії 4.0 (RFC6350) або 3.0 (RFC2426).",
    "Contact could not be moved." : "Неможливо перемістити контакт.",
    "Contact could not be saved." : "Неможливо зберегти контакт.",
    "Importing…" : "Імпортування…",
    "Display name" : "Ім'я для відображення",
    "Nickname" : "Прізвисько",
    "Detailed name" : "Повне ім'я",
    "Notes" : "Нотатки",
    "Website" : "Web-сайт",
    "Federated Cloud ID" : "Об'єднаний Хмарний Ідентіфікатор",
    "Home" : "Домашня адреса",
    "Work" : "Робота",
    "Other" : "Інше",
    "Groups" : "Групи",
    "Birthday" : "День народження",
    "Anniversary" : "Річниця",
    "Date of death" : "Дата смерті",
    "Email" : "E-mail",
    "Instant messaging" : "Швидкі повідомлення",
    "Phone" : "Телефон",
    "Mobile" : "Мобільний",
    "Work mobile" : "Робочий мобільний",
    "Fax" : "Факс",
    "Fax home" : "Домашній факс",
    "Fax work" : "Робочий факс",
    "Pager" : "Пейджер",
    "Voice" : "Голос",
    "Car" : "Машина",
    "Work pager" : "Робочий пейджер",
    "Social network" : "Соціальна мережа",
    "Spouse" : "Чоловік\\Дружина",
    "Child" : "Дитина",
    "Mother" : "Мати",
    "Father" : "Батько",
    "Brother" : "Брат",
    "Sister" : "Сестра",
    "Friend" : "Друг",
    "Colleague" : "Колега",
    "Gender" : "Стать",
    "Female" : "Жінка",
    "Male" : "Чоловік",
    "Details" : "Деталі",
    "Settings" : "Налаштування"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
